function f=pitch2hz(n)
% PITCH2HZ - convert pitch in semitones rel A440 to frequency
% freq=pitch2hz(n)
% f: frequency in Hz
% n: pitch in semitones relative to A 440Hz.
f=440*exp(log(2)*n/12);


						
